==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/viewer/l10n/mk.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Прегледувач",
    "Simple file viewer with slideshow for media" : "Едноставен прегледувач на датотеки со слајдшоу за медиуми",
    "Your browser does not support audio." : "Вашиот прелистувач не поддржува звук.",
    "Error loading {name}" : "Грешка при вчитување на  {name}",
    "Cancel" : "Откажи",
    "Your browser does not support videos." : "Вашиот прелистувач не поддржува видео.",
    "There is no plugin available to display this file type" : "Нема достапен додаток за приказ на овој вид на датотека",
    "Edit" : "Уреди",
    "Exit full screen" : "Излез од цел екран",
    "Full screen" : "Цел екран",
    "Open sidebar" : "Отвори странична лента",
    "Download" : "Преземи",
    "Delete" : "Избриши",
    "View" : "Погледни",
    "Name" : "Име",
    "Save" : "Зачувај",
    "Save as" : "Зачувај како",
    "Back" : "Назад",
    "Loading …" : "Се вчитува…",
    "Reset" : "Ресетирање",
    "All changes will be lost." : "Сите промени ќе се изгубат.",
    "Are you sure you want to continue?" : "Дали си сигурен дека сакаш да продолжиш?",
    "Apply" : "Примени",
    "Warning" : "Предупредување",
    "Confirm" : "Потврди",
    "Discard changes" : "Орфрли промени",
    "Undo" : "Назад",
    "Redo" : "Напред",
    "Show original image" : "Прикажи ја оргиналната слика",
    "Zoom in" : "Зумирај",
    "Zoom out" : "Од зумирај",
    "Toggle zoom menu" : "Прикажи мени за зумирање",
    "Adjust" : "Прилагоди",
    "Fine-tune" : "Фимо прилагодување",
    "Filters" : "Филтри",
    "Watermark" : "Воден печат",
    "Draw" : "Нацрт",
    "Resize" : "Промени големина",
    "Invalid image." : "Невалидна слика.",
    "Error while uploading the image." : "Грешка при прикачување на сликата.",
    "are not images" : "не се слики",
    "is not an image" : "не е слика",
    "to be uploaded" : "за да се орикачат",
    "Crop" : "Пресечи",
    "Original" : "Оргинал",
    "Custom" : "Прилагодено",
    "Square" : "Квадрат",
    "Landscape" : "Пејсаж",
    "Portrait" : "Портрет",
    "Ellipse" : "Елипса",
    "Classic TV" : "Класичен ТВ",
    "Arrow" : "Стрела",
    "Blur" : "Замаглување",
    "Brightness" : "Светлина",
    "Contrast" : "Контраст",
    "Un-flip X" : "одпреврти X",
    "Flip X" : "Преврти X",
    "Un-flip Y" : "Одпреврти Y",
    "Flip Y" : "Преврти Y",
    "Hue" : "Нијанса",
    "Saturation" : "Сатурација",
    "Value" : "Вредност",
    "Image" : "Слика",
    "Importing …" : "Увезување ...",
    "+ Add image" : "+ Додади слика",
    "Line" : "Линија",
    "Pen" : "Пенкало",
    "Polygon" : "Полигон",
    "Sides" : "Страни",
    "Rectangle" : "Правоаголник",
    "Corner Radius" : "Радиус на аголот",
    "Width in pixels" : "Ширина во пиксели",
    "Height in pixels" : "Висина во пиксели",
    "Toggle ratio lock" : "Вклучи/исклучи заклучување на соодносот",
    "Reset to original image size" : "Ресетирај на оригиналната големина",
    "Rotate" : "Ротирај",
    "Text" : "Текст",
    "Text spacing" : "Растојание во текстот",
    "Text alignment" : "Порамнување на текстот",
    "Size" : "Големина",
    "Letter spacing" : "Растојание на буквите",
    "Line height" : "Висина на линијата",
    "Warmth" : "Топлина",
    "+ Add watermark" : "+ Додај воден печат",
    "Choose watermark type" : "Изберете тип на воден печат",
    "Upload watermark" : "Прикачи воден печат",
    "Add as text" : "Додади како текст",
    "Padding" : "Дополнување",
    "Shadow" : "Сенка",
    "Horizontal" : "Хоризонтално",
    "Vertical" : "Вертикално",
    "Opacity" : "Проѕирност",
    "Position" : "Позиција",
    "Stroke" : "Stroke",
    "Save image as" : "Зачувај ја сликата како",
    "Extension" : "Екстензија",
    "Name is required." : "Потребно е име.",
    "Quality" : "Квалитет",
    "Saved image size (width x height)" : "Зачувана големина на сликата (ширина x висина)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Избраната област за сечење е помала од применетата промена на големината, што може да предизвика намалување на квалитетот",
    "Actual size (100%)" : "Актуелна големина (100%)",
    "Fit size" : "Соодветна големина"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/viewer/l10n/mk.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Прегледувач",
    "Simple file viewer with slideshow for media" : "Едноставен прегледувач на датотеки со слајдшоу за медиуми",
    "Your browser does not support audio." : "Вашиот прелистувач не поддржува звук.",
    "Error loading {name}" : "Грешка при вчитување на  {name}",
    "Cancel" : "Откажи",
    "Your browser does not support videos." : "Вашиот прелистувач не поддржува видео.",
    "There is no plugin available to display this file type" : "Нема достапен додаток за приказ на овој вид на датотека",
    "Edit" : "Уреди",
    "Exit full screen" : "Излез од цел екран",
    "Full screen" : "Цел екран",
    "Open sidebar" : "Отвори странична лента",
    "Download" : "Преземи",
    "Delete" : "Избриши",
    "View" : "Погледни",
    "Name" : "Име",
    "Save" : "Зачувај",
    "Save as" : "Зачувај како",
    "Back" : "Назад",
    "Loading …" : "Се вчитува…",
    "Reset" : "Ресетирање",
    "All changes will be lost." : "Сите промени ќе се изгубат.",
    "Are you sure you want to continue?" : "Дали си сигурен дека сакаш да продолжиш?",
    "Apply" : "Примени",
    "Warning" : "Предупредување",
    "Confirm" : "Потврди",
    "Discard changes" : "Орфрли промени",
    "Undo" : "Назад",
    "Redo" : "Напред",
    "Show original image" : "Прикажи ја оргиналната слика",
    "Zoom in" : "Зумирај",
    "Zoom out" : "Од зумирај",
    "Toggle zoom menu" : "Прикажи мени за зумирање",
    "Adjust" : "Прилагоди",
    "Fine-tune" : "Фимо прилагодување",
    "Filters" : "Филтри",
    "Watermark" : "Воден печат",
    "Draw" : "Нацрт",
    "Resize" : "Промени големина",
    "Invalid image." : "Невалидна слика.",
    "Error while uploading the image." : "Грешка при прикачување на сликата.",
    "are not images" : "не се слики",
    "is not an image" : "не е слика",
    "to be uploaded" : "за да се орикачат",
    "Crop" : "Пресечи",
    "Original" : "Оргинал",
    "Custom" : "Прилагодено",
    "Square" : "Квадрат",
    "Landscape" : "Пејсаж",
    "Portrait" : "Портрет",
    "Ellipse" : "Елипса",
    "Classic TV" : "Класичен ТВ",
    "CinemaScope" : "CinemaScope (кино формат)",
    "Arrow" : "Стрела",
    "Blur" : "Замаглување",
    "Brightness" : "Светлина",
    "Contrast" : "Контраст",
    "Un-flip X" : "одпреврти X",
    "Flip X" : "Преврти X",
    "Un-flip Y" : "Одпреврти Y",
    "Flip Y" : "Преврти Y",
    "HSV" : "HSV (тон, заситеност, вредност)",
    "Hue" : "Нијанса",
    "Saturation" : "Сатурација",
    "Value" : "Вредност",
    "Image" : "Слика",
    "Importing …" : "Увезување ...",
    "+ Add image" : "+ Додади слика",
    "Line" : "Линија",
    "Pen" : "Пенкало",
    "Polygon" : "Полигон",
    "Sides" : "Страни",
    "Rectangle" : "Правоаголник",
    "Corner Radius" : "Радиус на аголот",
    "Width in pixels" : "Ширина во пиксели",
    "Height in pixels" : "Висина во пиксели",
    "Toggle ratio lock" : "Вклучи/исклучи заклучување на соодносот",
    "Reset to original image size" : "Ресетирај на оригиналната големина",
    "Rotate" : "Ротирај",
    "Text" : "Текст",
    "Text spacing" : "Растојание во текстот",
    "Text alignment" : "Порамнување на текстот",
    "Font family" : "Тип на фонт",
    "Size" : "Големина",
    "Letter spacing" : "Растојание на буквите",
    "Line height" : "Висина на линијата",
    "Warmth" : "Топлина",
    "+ Add watermark" : "+ Додај воден печат",
    "Choose watermark type" : "Изберете тип на воден печат",
    "Upload watermark" : "Прикачи воден печат",
    "Add as text" : "Додади како текст",
    "Padding" : "Дополнување",
    "Shadow" : "Сенка",
    "Horizontal" : "Хоризонтално",
    "Vertical" : "Вертикално",
    "Opacity" : "Проѕирност",
    "Position" : "Позиција",
    "Stroke" : "Stroke",
    "Save image as" : "Зачувај ја сликата како",
    "Extension" : "Екстензија",
    "Name is required." : "Потребно е име.",
    "Quality" : "Квалитет",
    "Saved image size (width x height)" : "Зачувана големина на сликата (ширина x висина)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Избраната област за сечење е помала од применетата промена на големината, што може да предизвика намалување на квалитетот",
    "Actual size (100%)" : "Актуелна големина (100%)",
    "Fit size" : "Соодветна големина"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
